from simpleicons.icon import Icon
icon= Icon(
    title="CEVO",
    slug="cevo",
    hex="1EABE2",
    source="https://cevo.com/",
    svg="""<svg xmlns="http://www.w3.org/2000/svg" role="img" viewBox="0 0 24 24"><title>CEVO icon</title><path d="M3.5 6h12l6 10.3L24 12 18 1.6H6L3.5 6zm-.9 1.5L0 12l6 10.4h12l2.6-4.5-2.5-4.3-2.6 4.5h-7L5 12l2.6-4.5h-5z"/></svg>""",
    guidelines=None,
    license=None,
)
