from simpleicons.icon import Icon
icon= Icon(
    title="Farfetch",
    slug="farfetch",
    hex="000000",
    source="https://www.farfetch.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Farfetch icon</title><path d="M9.635 0L4.883 4.811V24h4.752v-9.593h7.119V9.6H9.635V4.811h9.482V0Z"/></svg>""",
    guidelines=None,
    license=None,
)
